@@ -14,41 +14,31 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import pyparticles.pset.particles_set as ps
+
 
 import pyparticles.animation.animation as pan
 
-
-#import pyparticles.forces.gravity as gr
-
-import matplotlib.animation as animation
-
 import numpy as np
 
 import pyparticles.ogl.trackball as trk
 import pyparticles.ogl.axis_ogl as axgl
 import pyparticles.ogl.translate_scene as tran
+import pyparticles.ogl.draw_vector_field as dvf
 import pyparticles.utils.time_formatter as tf
 import pyparticles.ogl.draw_particles_ogl as drp
 
-import ctypes 
+from OpenGL.GL import *
+from OpenGL.GLUT import *
+from OpenGL.GLU import *
+
+import time
 
 
-import sys
-
-try:
-    from OpenGL.GL import *
-    from OpenGL.GLUT import *
-    from OpenGL.GLU import *
-except:
-    _____foo = None
-
-    
-    
 def InitGL( Width , Height , ReSizeFun ):
     """
-    Inizialise OpenGl 
+    Initialize OpenGl 
     """
+    
     glClearColor(0.0, 0.0, 0.0, 0.0)    
     glClearDepth(1.0)                   
     glDepthFunc(GL_LESS)                
@@ -82,9 +72,9 @@ def InitLight() :
     mat_specular = np.array( [  1.0 , 1.0 , 1.0 , 1.0  ] )
     high_shininess = np.array( [  100.0  ] )
     
-    #glEnable(GL_LIGHT0)
-    #glEnable(GL_NORMALIZE)
-    #glEnable(GL_COLOR_MATERIAL)
+    glEnable(GL_LIGHT0)
+    glEnable(GL_NORMALIZE)
+    glEnable(GL_COLOR_MATERIAL)
     #glEnable(GL_LIGHTING)
     
     glLightfv(GL_LIGHT0, GL_AMBIENT,  light_ambient)
@@ -98,15 +88,9 @@ def InitLight() :
     glMaterialfv(GL_FRONT, GL_SHININESS, high_shininess)    
 
 def enableLight():
-    glEnable(GL_LIGHT0)
-    glEnable(GL_NORMALIZE)
-    glEnable(GL_COLOR_MATERIAL)
     glEnable(GL_LIGHTING)
     
 def disableLight():
-    glDisable(GL_LIGHT0)
-    glDisable(GL_NORMALIZE)
-    glDisable(GL_COLOR_MATERIAL)
     glDisable(GL_LIGHTING)    
     
 
@@ -115,20 +99,18 @@ def DrawGLScene():
     Draw the current particle scene.
     """
     
-    j = DrawGLScene.stream()
+    # Simulation step
+    DrawGLScene.stream()
     
     tr = DrawGLScene.animation.translation
-    unit = DrawGLScene.animation.pset.unit
-    mass_unit = DrawGLScene.animation.pset.mass_unit
     
     sim_time = DrawGLScene.animation.ode_solver.time
-    
-    
+        
     fm = tf.MyTimeFormatter()
         
     glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT )
     
-    Set2DMode( animation )
+    Set2DMode( )
         
     glut_print( 0.02 , 0.02 , GLUT_BITMAP_9_BY_15 , fm.to_str( sim_time ) , 1.0 , 1.0 , 1.0 , 1.0 )
     
@@ -140,7 +122,6 @@ def DrawGLScene():
     
     SetPerspective( DrawGLScene.animation )
 
-    
     glPushMatrix()
     
     glEnable (GL_FOG)
@@ -148,7 +129,7 @@ def DrawGLScene():
     
     glLoadIdentity()  
     
-    if DrawGLScene.animation.state == "trackball_down" and DrawGLScene.animation.motion or  joystick_func.animation.joy_state == "joy_on":
+    if DrawGLScene.animation.state == "trackball_down" and DrawGLScene.animation.motion or joystick_func.animation.joy_state == "joy_on":
         ( ax , ay , az ) = DrawGLScene.animation.rotatation_axis
         angle = DrawGLScene.animation.rotation_angle
         glRotatef( angle , ax , ay , az )
@@ -162,16 +143,25 @@ def DrawGLScene():
     glTranslatef( tr[0] , tr[1] , -15.0 )          
     glMultMatrixf( DrawGLScene.animation.rot_matrix )
 
+    if DrawGLScene.animation.light :
+        enableLight()
+
     DrawGLScene.animation.draw_particles.draw()
     
+    if DrawGLScene.animation.light :
+        disableLight()
+    
     if DrawGLScene.animation.view_axis :
         DrawGLScene.animation.axis.draw_axis()    
         
+    if DrawGLScene.animation.draw_vector_field :
+        DrawGLScene.animation.vector_field.draw()
+        
     glPopMatrix()
     glutSwapBuffers()
 
 
-def Set2DMode( animation ):
+def Set2DMode(  ):
     
     glMatrixMode(GL_PROJECTION)
     glLoadIdentity()
@@ -196,8 +186,6 @@ def ReSizeGLScene(Width, Height):
     
     if Height == 0:                        
         Height = 1
-
-    per = ReSizeGLScene.animation.perspective
     
     MousePressed.animation.win_size = ( Width , Height )
     glViewport(0, 0, Width, Height)
@@ -225,10 +213,14 @@ def KeyPressed( c , x , y ):
         KeyPressed.animation.draw_particles.set_particle_model( model="teapot" )
         
     if c == 'L' :
-        enableLight()
+        KeyPressed.animation.light = True
         
     if c == 'l' :
-        disableLight()
+        KeyPressed.animation.light = False
+        
+    if c == 'v' :
+        KeyPressed.animation.draw_vector_field = not KeyPressed.animation.draw_vector_field
+        
         
 
 
@@ -318,6 +310,9 @@ def print_help():
     y -= 0.05
     glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "Lighting - L: On  l: OFF " , 1 , 1 , 1 , 1 )
     
+    y -= 0.05
+    glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "v: Toggle vector field " , 1 , 1 , 1 , 1 )
+    
     y -= 0.1    
     glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "h: Toggle help message" , 1 , 1 , 1 , 1 )
     
@@ -336,9 +331,7 @@ def print_measures():
     
 
 def glut_print( x,  y,  font,  text, r,  g , b , a):
-    
-    pass
-    
+        
     blending = False 
     if glIsEnabled(GL_BLEND) :
         blending = True
@@ -346,14 +339,12 @@ def glut_print( x,  y,  font,  text, r,  g , b , a):
     glPushMatrix()
     glColor3f(1,1,1)
     glRasterPos2f(x,y)
-    #
         
     text = bytes( text.encode("ascii") ) 
     
     glutBitmapString( font , text ) 
     glPopMatrix()
-    #
-    #
+
     if not blending :
         glDisable(GL_BLEND) 
 
@@ -385,6 +376,8 @@ class AnimatedGl( pan.Animation ):
         self.__trackb = trk.TrackBall( self.win_size )
         self.__tran   = tran.TranslateScene( self.win_size )
         
+        self.__light = False
+        
         self.rot_matrix = np.array( [ 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1 ]  )
         
         self.state = "trackball_down"
@@ -396,6 +389,9 @@ class AnimatedGl( pan.Animation ):
         
         self.axis = axgl.AxisOgl()
         self.draw_particles = drp.DrawParticlesGL()
+        
+        self.__draw_vector_field = False
+        self.vector_field = None
     
 
     def get_pset(self):
@@ -427,6 +423,15 @@ class AnimatedGl( pan.Animation ):
     
     rotation_angle = property( get_rot_angle , set_rot_angle )
     
+    
+    def set_light( self , sw ):
+        self.__light = sw
+        
+    def get_light( self ):
+        return self.__light
+    
+    light = property( get_light , set_light , doc="enable or disable (True or False) the opengl lighting"  )
+
 
     def init_rotation( self , angle , axis ):
         self.__init_rot = list( [ angle , axis ] )
@@ -487,7 +492,7 @@ class AnimatedGl( pan.Animation ):
         self.trackball.win_size = w_size
         self.translate_scene.win_size = w_size
         
-    win_size = property( get_win_size , set_win_size )
+    win_size = property( get_win_size , set_win_size , doc="get or set the size of the current window. The size is a tuple: (w,h)")
     
     
     def get_trajectory( self ) :
@@ -497,7 +502,7 @@ class AnimatedGl( pan.Animation ):
         super(AnimatedGl,self).set_trajectory( tr )
         self.draw_particles.trajectory = tr
         
-    trajectory = property( get_trajectory , set_trajectory , doc="enable or disable the trajectory" )
+    trajectory = property( get_trajectory , set_trajectory , doc="enable or disable (True or False) the trajectory" )
     
     
     def get_trajectory_step( self ) :
@@ -510,7 +515,26 @@ class AnimatedGl( pan.Animation ):
     trajectory_step = property( get_trajectory_step , set_trajectory_step , doc="set or get the step for drawing the trajectory" )
 
     
+    def get_draw_vector_field(self):
+        return self.__draw_vector_field
     
+    def set_draw_vector_field( self , f ):
+        self.__draw_vector_field = f
+        
+    draw_vector_field = property( get_draw_vector_field , set_draw_vector_field , doc="enable or disable (True of False) vector filed drawing (if available)" )
+    
+    
+    def add_vector_field_fun( self , fun ,  unit , density=1.0 , color_fun=None ):
+        
+        if self.vector_field == None :
+            
+            lims = [ self.xlim[0] , self.xlim[1] , self.ylim[0] , self.ylim[1] , self.zlim[0] , self.zlim[1] ]
+            
+            self.vector_field = dvf.DrawVectorField( lims , density )
+        
+        self.vector_field.add_vector_fun( fun , unit , color_fun )
+        
+        
     def zoom_scene( self , f ):
         
         (w,h) = MousePressed.animation.win_size
@@ -555,7 +579,6 @@ class AnimatedGl( pan.Animation ):
         glutDisplayFunc(DGLS)
         glutIdleFunc(DGLS)
         
-        
         ReSizeFun = ReSizeGLScene
         ReSizeFun.animation = self
         
@@ -594,16 +617,24 @@ class AnimatedGl( pan.Animation ):
             glRotatef( self.__init_rot[0] , self.__init_rot[1][0] , self.__init_rot[1][1] , self.__init_rot[1][2] )
             self.rot_matrix = glGetFloatv( GL_MODELVIEW_MATRIX )
             glPopMatrix()
+            
+        if self.vector_field != None :
+            self.vector_field.ogl_init()
         
         
     def data_stream(self):
         
+        #a = time.time()
+        
         self.pset.log()
         
         self.ode_solver.step()
         
         self.perform_measurement()
         
+        #b = time.time()
+        #print( "step_time = %f " % (b-a) )
+
         return self.ode_solver.steps_cnt
         
     
