@@ -15,9 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import numpy as np
-import sys
 import scipy.spatial.distance as dist
-
 import pyparticles.forces.force as fr
 
 class Gravity( fr.Force ) :
@@ -80,8 +78,10 @@ class Gravity( fr.Force ) :
         
         self.__Fm[:] = - self.__G * self.__M[:] / ( ( self.__D[:] ) ** 3.0 )
 
-        for j in range( self.__size ) :
-            self.__Fm[j,j] = 0.0
+        #for j in range( self.__size ) :
+        #    self.__Fm[j,j] = 0.0
+            
+        np.fill_diagonal( self.__Fm , 0.0 )
         
         #print(" --- Fm ----")
         #print( self.__Fm[:,:] )
